Index: imaps-frontend/node_modules/@eslint-community/regexpp/index.d.ts
===================================================================
--- imaps-frontend/node_modules/@eslint-community/regexpp/index.d.ts	(revision d56544918790c0c3bc50f2f0a98c99f3d2988ccf)
+++ imaps-frontend/node_modules/@eslint-community/regexpp/index.d.ts	(revision 79a03170cdde4e801d12257ee86723774970427b)
@@ -52,4 +52,5 @@
     | Group
     | LookaroundAssertion
+    | Modifiers
     | Pattern
     | Quantifier
@@ -64,5 +65,6 @@
     | Character
     | CharacterSet
-    | Flags;
+    | Flags
+    | ModifierFlags;
   /**
    * The type which includes all atom nodes.
@@ -148,4 +150,5 @@
     type: "Group";
     parent: Alternative | Quantifier;
+    modifiers: Modifiers | null;
     alternatives: Alternative[];
   }
@@ -449,4 +452,32 @@
   }
   /**
+   * The modifiers.
+   */
+  export interface Modifiers extends NodeBase {
+    type: "Modifiers";
+    parent: Group;
+    /**
+     * The add modifier flags.
+     */
+    add: ModifierFlags;
+    /**
+     * The remove modifier flags.
+     *
+     * `null` means no remove modifier flags. e.g. `(?ims:x)`
+     * The reason for `null` is that there is no position where the remove modifier flags appears. Must be behind the minus mark.
+     */
+    remove: ModifierFlags | null;
+  }
+  /**
+   * The modifier flags.
+   */
+  export interface ModifierFlags extends NodeBase {
+    type: "ModifierFlags";
+    parent: Modifiers;
+    dotAll: boolean;
+    ignoreCase: boolean;
+    multiline: boolean;
+  }
+  /**
    * The flags.
    */
@@ -491,5 +522,5 @@
        * - `2023` added more valid Unicode Property Escapes.
        * - `2024` added `v` flag.
        * - `2025` added duplicate named capturing groups.
        */
       ecmaVersion?: EcmaVersion;
@@ -580,5 +611,5 @@
        * - `2023` added more valid Unicode Property Escapes.
        * - `2024` added `v` flag.
        * - `2025` added duplicate named capturing groups.
        */
       ecmaVersion?: EcmaVersion;
@@ -692,4 +723,51 @@
        */
       onGroupLeave?: (start: number, end: number) => void;
+      /**
+       * A function that is called when the validator entered a modifiers.
+       * @param start The 0-based index of the first character.
+       */
+      onModifiersEnter?: (start: number) => void;
+      /**
+       * A function that is called when the validator left a modifiers.
+       * @param start The 0-based index of the first character.
+       * @param end The next 0-based index of the last character.
+       */
+      onModifiersLeave?: (start: number, end: number) => void;
+      /**
+       * A function that is called when the validator found an add modifiers.
+       * @param start The 0-based index of the first character.
+       * @param end The next 0-based index of the last character.
+       * @param flags flags.
+       * @param flags.ignoreCase `i` flag.
+       * @param flags.multiline `m` flag.
+       * @param flags.dotAll `s` flag.
+       */
+      onAddModifiers?: (
+        start: number,
+        end: number,
+        flags: {
+          ignoreCase: boolean;
+          multiline: boolean;
+          dotAll: boolean;
+        }
+      ) => void;
+      /**
+       * A function that is called when the validator found a remove modifiers.
+       * @param start The 0-based index of the first character.
+       * @param end The next 0-based index of the last character.
+       * @param flags flags.
+       * @param flags.ignoreCase `i` flag.
+       * @param flags.multiline `m` flag.
+       * @param flags.dotAll `s` flag.
+       */
+      onRemoveModifiers?: (
+        start: number,
+        end: number,
+        flags: {
+          ignoreCase: boolean;
+          multiline: boolean;
+          dotAll: boolean;
+        }
+      ) => void;
       /**
        * A function that is called when the validator entered a capturing group.
@@ -978,4 +1056,6 @@
     Flags,
     Group,
+    ModifierFlags,
+    Modifiers,
     Node,
     Pattern,
@@ -1033,4 +1113,8 @@
       onGroupEnter?: (node: Group) => void;
       onGroupLeave?: (node: Group) => void;
+      onModifierFlagsEnter?: (node: ModifierFlags) => void;
+      onModifierFlagsLeave?: (node: ModifierFlags) => void;
+      onModifiersEnter?: (node: Modifiers) => void;
+      onModifiersLeave?: (node: Modifiers) => void;
       onPatternEnter?: (node: Pattern) => void;
       onPatternLeave?: (node: Pattern) => void;
@@ -491,5 +522,5 @@
        * - `2023` added more valid Unicode Property Escapes.
        * - `2024` added `v` flag.
-       * - `2025` added duplicate named capturing groups.
+       * - `2025` added duplicate named capturing groups, modifiers.
        */
       ecmaVersion?: EcmaVersion;
@@ -580,5 +611,5 @@
        * - `2023` added more valid Unicode Property Escapes.
        * - `2024` added `v` flag.
-       * - `2025` added duplicate named capturing groups.
+       * - `2025` added duplicate named capturing groups, modifiers.
        */
       ecmaVersion?: EcmaVersion;
